@@ -32,9 +32,6 @@ OC.L10N.register(
     "Select account" : "Избери профил",
     "To" : "До",
     "Contact or email address …" : "Контакт или имейл адрес...",
-    "+ Copy" : "+ Копие",
-    "Copy" : "Копие",
-    "Blind copy" : "Скрито копие",
     "Subject" : "Тема",
     "Subject …" : "Тема...",
     "Draft saved" : "Черновата записана",
@@ -72,7 +69,6 @@ OC.L10N.register(
     "Mark all as read" : "Маркирай всички като прочетени",
     "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
     "Add subfolder" : "Добави подпапка",
-    "{total} messages" : "{total} съобщения",
     "Loading …" : "Зарежда …",
     "No message selected" : "Не е избрано съобщение",
     "Signature" : "Подпис",
