@@ -35,9 +35,10 @@ OC.L10N.register(
     "From" : "De",
     "Select account" : "Selecciona un compte",
     "To" : "A",
-    "+ Copy" : "+ Copia",
-    "Copy" : "Copia",
+    "+ CC/BCC" : "+ Cc / C/o",
+    "CC" : "Cc",
     "No contacts found." : "No s'han trobat contactes.",
+    "BCC" : "C/o",
     "Subject" : "Assumpte",
     "Subject …" : "Assumpte …",
     "Write message …" : "Escriu missatge …",
@@ -89,8 +90,6 @@ OC.L10N.register(
     "Mark all as read" : "Marca-ho tot com a llegit",
     "Mark all messages of this folder as read" : "Marca tots els missatges d'aquesta carpeta com a llegits",
     "Add subfolder" : "Afegeix una subcarpeta",
-    "{total} messages" : "{total} missatges",
-    "{unread} unread of {total}" : "{unread} no llegits de {total}",
     "Loading …" : "Carregant …",
     "Could not load your draft" : "No s’ha pogut carregar el vostre esborrany",
     "Could not load original message" : "No s'ha pogut carregar el missatge original",
