@@ -4,6 +4,7 @@ OC.L10N.register(
     "Mail" : "ایمیل",
     "Auto detect failed. Please use manual mode." : "شناسایی خودکار با شکست مواجه شد. لطفا از حالت دستی استفاده کنید.",
     "Name" : "نام",
+    "Mail Address" : "آدرس رایانامه",
     "Password" : "گذرواژه",
     "None" : "هیچ‌کدام",
     "SSL/TLS" : "SSL/TLS",
@@ -13,7 +14,6 @@ OC.L10N.register(
     "Connect" : "اتصال",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
     "Select account" : "حساب را انتخاب کنید",
-    "Copy" : "کپی کردن",
     "Sending …" : "در حال ارسال ...",
     "Retry" : "تلاش دوباره",
     "Message sent!" : "پیام ارسال شد!",
@@ -26,6 +26,7 @@ OC.L10N.register(
     "Add folder" : "Add folder",
     "Delete account" : "حذف حساب کاربری",
     "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
+    "Signature" : "امضا",
     "General" : "عمومی",
     "User" : "User",
     "Host" : "میزبان",
