@@ -33,7 +33,6 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
     "Select account" : "Valitse tili",
-    "Copy" : "Kopioi",
     "Subject" : "Aihe",
     "Saving draft …" : "Tallennetaan luonnosta…",
     "Draft saved" : "Luonnos tallennettu",
@@ -80,7 +79,6 @@ OC.L10N.register(
     "Mark all as read" : "Merkitse kaikki luetuiksi",
     "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
     "Add subfolder" : "Lisää alikansio",
-    "{total} messages" : "{total} viestiä",
     "Loading …" : "Ladataan…",
     "Could not load your draft" : "Luonnosta ei voitu ladata",
     "No message selected" : "Viestiä ei ole valittu",
