@@ -31,7 +31,6 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
     "Keyboard shortcuts" : "키보드 단축키",
     "Select account" : "계정 선택",
-    "Copy" : "복사",
     "Subject" : "제목",
     "Upload attachment" : "첨부 파일 업로드",
     "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
@@ -62,8 +61,6 @@ OC.L10N.register(
     "Show all folders" : "모든 폴더 보기",
     "Collapse folders" : "폴더 접기",
     "Mark all as read" : "모두 읽은 것으로 표시",
-    "{total} messages" : "{total} 개의 메세지",
-    "{unread} unread of {total}" : "{total} 개 중 {unread} 개를 읽지 않음",
     "Loading …" : "불러오는 중 …",
     "Signature" : "서명",
     "General" : "일반",
