@@ -5,6 +5,7 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
     "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
     "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
+    "Embedded message %s" : "Įterptas laiškas %s",
     "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
     "Auto" : "Automatiškai",
     "Name" : "Vardas",
@@ -34,10 +35,12 @@ OC.L10N.register(
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ieškote būdo kaip šifruoti savo el. laiškus? Įsidiekite Mailvelope naršyklės plėtinį!",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
+    "To" : "Kam",
     "Contact or email address …" : "Adresatas ar el. pašto adresas…",
-    "Copy" : "Kopijuoti",
+    "+ CC/BCC" : "+ CC/BCC",
+    "CC" : "CC",
     "No contacts found." : "Adresatų nerasta.",
-    "Blind copy" : "Nematomoji kopija",
+    "BCC" : "BCC",
     "Subject" : "Tema",
     "Subject …" : "Tema…",
     "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
@@ -75,6 +78,7 @@ OC.L10N.register(
     "Import into calendar" : "Importuoti į kalendorių",
     "Download attachment" : "Atsisiųsti priedą",
     "Save to Files" : "Įrašyti į Failus",
+    "Embedded message" : "Įterptas laiškas",
     "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
     "Save all to Files" : "Įrašyti visus į Failus",
     "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
@@ -94,9 +98,12 @@ OC.L10N.register(
     "Add subfolder" : "Pridėti poaplankį",
     "Loading …" : "Įkeliama…",
     "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
+    "Could not load original message" : "Nepavyko įkelti pradinio laiško",
     "Signature" : "Parašas",
     "Signature …" : "Parašas…",
     "Save signature" : "Įrašyti parašą",
+    "Import into {calendar}" : "Importuoti į {calendar}",
+    "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
     "Could not create event" : "Nepavyko sukurti įvykio",
     "Airplane" : "Lėktuvas",
     "Reservation {id}" : "Rezervacija {id}",
@@ -116,7 +123,9 @@ OC.L10N.register(
     "Host" : "Serveris",
     "Port" : "Prievadas",
     "SMTP" : "SMTP",
+    "Apply and create/update for all users" : "Taikyti ir sukurti/atnaujinti visiems naudotojams",
     "Account settings" : "Paskyros nustatymai",
+    "Change name" : "Keisti vardą",
     "Mail server" : "Pašto serveris",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
     "Compose new message" : "Rašyti naują laišką",
