@@ -4,12 +4,28 @@ OC.L10N.register(
     "Mail" : "Mail",
     "Auto detect failed. Please use manual mode." : "L'autodeteccion a fracassat. Utilizatz lo mòde manual.",
     "Creating account failed: " : "La creacion del compte a fracassat :",
+    "Name" : "Nom",
+    "Password" : "Senhal",
+    "None" : "Pas cap",
+    "Save" : "Salvar",
     "Connect" : "Connectar",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
     "Sending …" : "Mandadís ...",
+    "Go back" : "Revenir en arrière",
     "Message sent!" : "Messatge mandat !",
     "Send" : "Mandar",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
+    "Delete" : "Suprimir",
+    "Reply" : "Respondre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
+    "Settings" : "Paramètres",
+    "Add folder" : "Add folder",
+    "Delete account" : "Delete account",
+    "Mark all as read" : "Marcar totes coma legits",
+    "General" : "Generals",
+    "User" : "User",
+    "Search" : "Search",
+    "Refresh" : "Refrescar",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Error loading message" : "Error al moment del cargament del messatge",
     "Continue to %s" : "Contunhar cap a %s"
