@@ -8,7 +8,7 @@ OC.L10N.register(
     "Name" : "Meno",
     "Mail Address" : "Emailová adresa",
     "Password" : "Heslo",
-    "Manual" : "Príručka",
+    "Manual" : "Ručné nastavenia",
     "IMAP Host" : "IMAP hostiteľ",
     "None" : "Žiadny",
     "SSL/TLS" : "SSL/TLS",
@@ -28,7 +28,6 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Použiť Gravatar a favicon avatary",
     "Keyboard shortcuts" : "Klávesové skratky",
     "Select account" : "Vybrať účet",
-    "Copy" : "Kopírovať",
     "Subject" : "Predmet",
     "Upload attachment" : "Nahrať prílohu",
     "Add attachment from Files" : "Pridať prílohu zo Súborov",
