@@ -5,6 +5,7 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
     "Updating account failed: " : "更新账号失败：",
     "Creating account failed: " : "创建账号失败：",
+    "Embedded message %s" : "嵌入式消息 %s",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
     "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
     "Auto" : "自动",
@@ -31,26 +32,27 @@ OC.L10N.register(
     "Connect" : "连接",
     "Add mail account" : "添加邮件账号",
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
+    "Register as application for mail links" : "注册为邮件链接应用",
     "Keyboard shortcuts" : "键盘快捷方式",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
     "From" : "发件人",
     "Select account" : "选择账号",
     "To" : "收件人",
     "Contact or email address …" : "联系人或邮箱地址...",
-    "+ Copy" : "+ 抄送",
-    "Copy" : "副本",
+    "+ CC/BCC" : "+ 抄送/密送",
+    "CC" : "抄送",
     "No contacts found." : "未找到联系人。",
-    "Blind copy" : "无信头副本",
+    "BCC" : "密送",
     "Subject" : "主题",
     "Subject …" : "标题...",
     "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
     "Write message …" : "编写消息...",
-    "Saving draft …" : "保存草稿 …",
+    "Saving draft …" : "正在保存草稿 …",
     "Draft saved" : "草稿已保存",
     "Upload attachment" : "上传附件",
     "Add attachment from Files" : "从文件添加附件",
     "Enable formatting" : "启用格式化",
-    "Uploading attachments …" : "上传附件 …",
+    "Uploading attachments …" : "正在上传附件…",
     "Sending …" : "正在发送…",
     "Error sending your message" : "发送您的消息时出错",
     "Go back" : "后退",
@@ -81,7 +83,8 @@ OC.L10N.register(
     "Import into calendar" : "导入到日历",
     "Download attachment" : "下载附件",
     "Save to Files" : "保存到“文件”",
-    "Choose a folder to store the attachment in" : "选择附件保存的文件夹",
+    "Embedded message" : "嵌入式消息",
+    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
     "Save all to Files" : "全部保存到文件",
     "Choose a folder to store the attachments in" : "选择附件保存的目录",
     "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
@@ -98,9 +101,9 @@ OC.L10N.register(
     "Mark all as read" : "标记所有为已读",
     "Mark all messages of this folder as read" : "将此文件夹中的所有消息都标记为已读",
     "Add subfolder" : "添加子文件夹",
-    "{total} messages" : "{total} 封邮件",
-    "{unread} unread of {total}" : "总共 {total} 封邮件，{unread} 封未读邮件",
     "Loading …" : "正在加载...",
+    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} 条未读，一共 {total} 条"],
     "Could not load your draft" : "无法加载您的草稿",
     "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
