@@ -29,12 +29,11 @@ use OCP\AppFramework\Http\Response;
 
 class HtmlResponse extends Response {
 
-	use CacheHeaders;
-
 	/** @var string */
 	private $content;
 
 	public function __construct(string $content) {
+		parent::__construct();
 		$this->content = $content;
 	}
 
