@@ -26,11 +26,11 @@ declare(strict_types=1);
 namespace OCA\Mail\Service\AutoConfig;
 
 use Exception;
-use OCA\Mail\Service\Logger;
+use OCP\ILogger;
 
 class IspDb {
 
-	/** @var Logger */
+	/** @var ILogger */
 	private $logger;
 
 	/** @var string[] */
@@ -42,7 +42,7 @@ class IspDb {
 		];
 	}
 
-	public function __construct(Logger $logger) {
+	public function __construct(ILogger $logger) {
 		$this->logger = $logger;
 	}
 
