@@ -86,10 +86,6 @@ class Manager {
 			// Fine, then we create a new one
 			$new = new MailAccount();
 			$new->setUserId($user->getUID());
-			if ($user->getDisplayName() !== $user->getUID()) {
-				// Only set if it's something meaningful
-				$new->setName($user->getDisplayName());
-			}
 			$new->setProvisioned(true);
 
 			$this->mailAccountMapper->insert(
@@ -125,6 +121,10 @@ class Manager {
 
 	private function updateAccount(IUser $user, MailAccount $account, Config $config): MailAccount {
 		$account->setEmail($config->buildEmail($user));
+		if ($user->getDisplayName() !== $user->getUID()) {
+			// Only set if it's something meaningful
+			$account->setName($user->getDisplayName());
+		}
 		$account->setInboundUser($config->buildImapUser($user));
 		$account->setInboundHost($config->getImapHost());
 		$account->setInboundPort($config->getImapPort());
